@@ -36,7 +36,8 @@ def multiple_replace(string, rep_dict):
 
     """
     pattern = re.compile(
-        "|".join([re.escape(k) for k in sorted(rep_dict,key=len,reverse=True)]),
+        "|".join([re.escape(k) for k in sorted(rep_dict, key=len,
+                                               reverse=True)]),
         flags=re.DOTALL
     )
     return pattern.sub(lambda x: rep_dict[x.group(0)], string)
