@@ -3,10 +3,12 @@ This module collects all of the stpipe.Step subclasses
 made available by this package.
 """
 from .dark_current.dark_current_step import DarkCurrentStep
+from .dq_init.dq_init_step import DQInitStep
 from .flatfield.flat_field_step import FlatFieldStep
 
 
 __all__ = [
     "DarkCurrentStep",
+    "DQInitStep",
     "FlatFieldStep",
 ]
